==> qtjambi-nfc-5.15.17-sources.jar: io/qt/nfc/QNdefNfcIconRecord.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QNdefNfcIconRecord</code></p>
 */
public class QNdefNfcIconRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr>QNdefNfcIconRecord()</code></p>
     */
    public QNdefNfcIconRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance);
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr>QNdefNfcIconRecord(QNdefRecord)</code></p>
     */
    public QNdefNfcIconRecord(io.qt.nfc.@NonNull QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr>data()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QByteArray data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QByteArray data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr>setData(QByteArray)</code></p>
     */
    @QtUninvokable
    public final void setData(io.qt.core.@NonNull QByteArray data){
        setData_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data));
    }
    
    @QtUninvokable
    private native void setData_native_cref_QByteArray(long __this__nativeId, long data);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNdefNfcIconRecord(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QNdefNfcIconRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNdefNfcIconRecord clone_native(long __this_nativeId);
}

==> qtjambi-nfc-5.15.19-sources.jar: io/qt/nfc/QNdefNfcIconRecord.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QNdefNfcIconRecord</code></p>
 */
public class QNdefNfcIconRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr/>QNdefNfcIconRecord()</code></p>
     */
    public QNdefNfcIconRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance);
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr/>QNdefNfcIconRecord(QNdefNfcIconRecord)</code></p>
     */
    public QNdefNfcIconRecord(io.qt.nfc.@NonNull QNdefNfcIconRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance, io.qt.nfc.QNdefNfcIconRecord other);
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr/>QNdefNfcIconRecord(QNdefRecord)</code></p>
     */
    public QNdefNfcIconRecord(io.qt.nfc.@NonNull QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcIconRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr/>data()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QByteArray data(){
        return data_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QByteArray data_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QNdefNfcIconRecord::<wbr/>setData(QByteArray)</code></p>
     */
    @QtUninvokable
    public final void setData(io.qt.core.@NonNull QByteArray data){
        setData_native_cref_QByteArray(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(data));
    }
    
    @QtUninvokable
    private native void setData_native_cref_QByteArray(long __this__nativeId, long data);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNdefNfcIconRecord(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QNdefNfcIconRecord::<wbr/>QNdefNfcIconRecord(QNdefNfcIconRecord)</code></p>
     */
    @QtUninvokable
    @Override
    public QNdefNfcIconRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNdefNfcIconRecord clone_native(long __this_nativeId);
    
    /**
     * <p>Overloaded function for {@link #setData(io.qt.core.QByteArray)}.</p>
     */
    @QtUninvokable
    public final void setData(byte @NonNull[] data) {
        setData(new io.qt.core.QByteArray(data));
    }
}
